#[repr(C)]pub struct CommandFlags(/* private fields */);Implementations
Sourceimpl CommandFlags
impl CommandFlags
pub const REQUIRES_TARGET: CommandFlags
pub const REQUIRES_PROCESS: CommandFlags
pub const REQUIRES_THREAD: CommandFlags
pub const REQUIRES_FRAME: CommandFlags
pub const REQUIRES_REG_CONTEXT: CommandFlags
pub const TRY_TARGET_API_LOCK: CommandFlags
pub const PROCESS_MUST_BE_LAUNCHED: CommandFlags
pub const PROCESS_MUST_BE_PAUSED: CommandFlags
pub const PROCESS_MUST_BE_TRACED: CommandFlags
Sourceimpl CommandFlags
impl CommandFlags
Sourcepub const fn empty() -> CommandFlags
pub const fn empty() -> CommandFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> CommandFlags
pub const fn all() -> CommandFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<CommandFlags>
pub const fn from_bits(bits: u32) -> Option<CommandFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> CommandFlags
pub const fn from_bits_truncate(bits: u32) -> CommandFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> CommandFlags
pub const fn from_bits_retain(bits: u32) -> CommandFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<CommandFlags>
pub fn from_name(name: &str) -> Option<CommandFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: CommandFlags) -> bool
pub const fn intersects(&self, other: CommandFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: CommandFlags) -> bool
pub const fn contains(&self, other: CommandFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: CommandFlags)
pub fn insert(&mut self, other: CommandFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: CommandFlags)
pub fn remove(&mut self, other: CommandFlags)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: CommandFlags)
pub fn toggle(&mut self, other: CommandFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: CommandFlags, value: bool)
pub fn set(&mut self, other: CommandFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: CommandFlags) -> CommandFlags
pub const fn intersection(self, other: CommandFlags) -> CommandFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: CommandFlags) -> CommandFlags
pub const fn union(self, other: CommandFlags) -> CommandFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: CommandFlags) -> CommandFlags
pub const fn difference(self, other: CommandFlags) -> CommandFlags
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: CommandFlags) -> CommandFlags
pub const fn symmetric_difference(self, other: CommandFlags) -> CommandFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> CommandFlags
pub const fn complement(self) -> CommandFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl CommandFlags
impl CommandFlags
Sourcepub const fn iter(&self) -> Iter<CommandFlags>
pub const fn iter(&self) -> Iter<CommandFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<CommandFlags>
pub const fn iter_names(&self) -> IterNames<CommandFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.