SBData

Struct SBData 

pub struct SBData {
    pub raw: SBDataRef,
}
A block of data.

Fields

raw: SBDataRef

The underlying raw SBDataRef.

Implementations

Source

impl SBData

pub fn is_valid(&self) -> bool

Check whether or not this is a valid SBData value.

pub fn get_address(&self, offset: lldb_offset_t) -> Result<lldb_addr_t, SBError>

Get address of the specified offset in this data region

pub fn read_raw_data( &self, offset: lldb_offset_t, buffer: &mut [u8], ) -> Result<(), SBError>

Reads the data at specified offset to the buffer.